Coverage report

# Coverage report: 14%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 26133 | 22538 | 0 | 14%
Bio | 15 | 0 | 0 | 100%
Bio.Align | 100 | 82 | 0 | 18%
Bio.Align.Generic | 96 | 73 | 0 | 24%
Bio.AlignIO | 122 | 99 | 0 | 19%
Bio.AlignIO.ClustalIO | 207 | 196 | 0 | 5%
Bio.AlignIO.EmbossIO | 152 | 139 | 0 | 9%
Bio.AlignIO.FastaIO | 249 | 239 | 0 | 4%
Bio.AlignIO.Interfaces | 40 | 20 | 0 | 50%
Bio.AlignIO.NexusIO | 91 | 78 | 0 | 14%
Bio.AlignIO.PhylipIO | 285 | 260 | 0 | 9%
Bio.AlignIO.StockholmIO | 194 | 174 | 0 | 10%
Bio.Alphabet | 193 | 138 | 0 | 28%
Bio.Alphabet.IUPAC | 26 | 0 | 0 | 100%
Bio.Data | 1 | 0 | 0 | 100%
Bio.Data.CodonTable | 300 | 48 | 0 | 84%
Bio.Data.IUPACData | 47 | 1 | 0 | 98%
Bio.Data.SCOPData | 1 | 0 | 0 | 100%
Bio.File | 326 | 245 | 0 | 25%
Bio.GenBank | 723 | 512 | 0 | 29%
Bio.GenBank.Scanner | 762 | 699 | 0 | 8%
Bio.GenBank.utils | 16 | 9 | 0 | 44%
Bio.Nexus | 1 | 0 | 0 | 100%
Bio.Nexus.Nexus | 1208 | 1084 | 0 | 10%
Bio.Nexus.Nodes | 102 | 75 | 0 | 26%
Bio.Nexus.Trees | 560 | 510 | 0 | 9%
Bio.Seq | 513 | 407 | 0 | 21%
Bio.SeqFeature | 494 | 354 | 0 | 28%
Bio.SeqIO | 164 | 117 | 0 | 29%
Bio.SeqIO.AbiIO | 133 | 111 | 0 | 17%
Bio.SeqIO.AceIO | 32 | 24 | 0 | 25%
Bio.SeqIO.FastaIO | 128 | 92 | 0 | 28%
Bio.SeqIO.IgIO | 52 | 45 | 0 | 13%
Bio.SeqIO.InsdcIO | 653 | 586 | 0 | 10%
Bio.SeqIO.Interfaces | 67 | 43 | 0 | 36%
Bio.SeqIO.PdbIO | 87 | 78 | 0 | 10%
Bio.SeqIO.PhdIO | 54 | 43 | 0 | 20%
Bio.SeqIO.PirIO | 56 | 48 | 0 | 14%
Bio.SeqIO.QualityIO | 382 | 331 | 0 | 13%
Bio.SeqIO.SeqXmlIO | 244 | 205 | 0 | 16%
Bio.SeqIO.SffIO | 644 | 598 | 0 | 7%
Bio.SeqIO.SwissIO | 105 | 94 | 0 | 10%
Bio.SeqIO.TabIO | 44 | 34 | 0 | 23%
Bio.SeqIO.UniprotIO | 331 | 315 | 0 | 5%
Bio.SeqRecord | 202 | 151 | 0 | 25%
Bio.Sequencing | 1 | 0 | 0 | 100%
Bio.Sequencing.Ace | 375 | 345 | 0 | 8%
Bio.Sequencing.Phd | 69 | 61 | 0 | 12%
Bio.SwissProt | 323 | 302 | 0 | 7%
Bio._py3k | 88 | 61 | 0 | 31%
Cookie | 201 | 201 | 0 | 0%
_LWPCookieJar | 93 | 93 | 0 | 0%
_MozillaCookieJar | 68 | 68 | 0 | 0%
argparse | 1177 | 1177 | 0 | 0%
bisect | 46 | 46 | 0 | 0%
bold_retriever | 3 | 0 | 0 | 100%
bold_retriever.bold_retriever | 149 | 46 | 0 | 69%
calendar | 385 | 385 | 0 | 0%
cgi | 584 | 584 | 0 | 0%
commands | 31 | 31 | 0 | 0%
contextlib | 63 | 63 | 0 | 0%
cookielib | 947 | 947 | 0 | 0%
ctypes | 341 | 341 | 0 | 0%
ctypes._endian | 35 | 35 | 0 | 0%
ctypes.util | 189 | 189 | 0 | 0%
email | 30 | 30 | 0 | 0%
email._parseaddr | 302 | 302 | 0 | 0%
email.base64mime | 55 | 55 | 0 | 0%
email.charset | 116 | 116 | 0 | 0%
email.encoders | 36 | 36 | 0 | 0%
email.encoders | 36 | 36 | 0 | 0%
email.errors | 16 | 16 | 0 | 0%
email.feedparser | 306 | 306 | 0 | 0%
email.generator | 173 | 173 | 0 | 0%
email.header | 235 | 235 | 0 | 0%
email.iterators | 32 | 32 | 0 | 0%
email.message | 346 | 346 | 0 | 0%
email.mime | 0 | 0 | 0 | 100%
email.mime.audio | 24 | 24 | 0 | 0%
email.mime.base | 9 | 9 | 0 | 0%
email.mime.image | 14 | 14 | 0 | 0%
email.mime.message | 11 | 11 | 0 | 0%
email.mime.multipart | 12 | 12 | 0 | 0%
email.mime.nonmultipart | 7 | 7 | 0 | 0%
email.mime.text | 8 | 8 | 0 | 0%
email.parser | 44 | 44 | 0 | 0%
email.quoprimime | 138 | 138 | 0 | 0%
email.utils | 155 | 155 | 0 | 0%
email.utils | 155 | 155 | 0 | 0%
encodings.ascii | 19 | 19 | 0 | 0%
encodings.hex_codec | 28 | 28 | 0 | 0%
encodings.idna | 164 | 164 | 0 | 0%
encodings.latin_1 | 19 | 19 | 0 | 0%
httplib | 704 | 704 | 0 | 0%
json | 39 | 39 | 0 | 0%
json.decoder | 222 | 222 | 0 | 0%
json.encoder | 241 | 241 | 0 | 0%
json.scanner | 52 | 52 | 0 | 0%
mimetools | 162 | 162 | 0 | 0%
mimetypes | 199 | 199 | 0 | 0%
netrc | 105 | 105 | 0 | 0%
quopri | 162 | 162 | 0 | 0%
requests | 26 | 5 | 0 | 81%
requests.adapters | 157 | 66 | 0 | 58%
requests.api | 22 | 8 | 0 | 64%
requests.auth | 126 | 102 | 0 | 19%
requests.certs | 6 | 1 | 0 | 83%
requests.compat | 56 | 13 | 0 | 77%
requests.cookies | 213 | 122 | 0 | 43%
requests.exceptions | 22 | 6 | 0 | 73%
requests.hooks | 18 | 4 | 0 | 78%
requests.models | 390 | 177 | 0 | 55%
requests.packages | 2 | 0 | 0 | 100%
requests.packages.chardet | 11 | 8 | 0 | 27%
requests.packages.urllib3 | 27 | 11 | 0 | 59%
requests.packages.urllib3._collections | 92 | 39 | 0 | 58%
requests.packages.urllib3.connection | 96 | 37 | 0 | 61%
requests.packages.urllib3.connectionpool | 242 | 124 | 0 | 49%
requests.packages.urllib3.contrib | 0 | 0 | 0 | 100%
requests.packages.urllib3.exceptions | 52 | 18 | 0 | 65%
requests.packages.urllib3.fields | 68 | 56 | 0 | 18%
requests.packages.urllib3.filepost | 39 | 27 | 0 | 31%
requests.packages.urllib3.packages | 2 | 0 | 0 | 100%
requests.packages.urllib3.packages.ordered_dict | 155 | 92 | 0 | 41%
requests.packages.urllib3.packages.six | 217 | 113 | 0 | 48%
requests.packages.urllib3.packages.ssl_match_hostname | 8 | 5 | 0 | 38%
requests.packages.urllib3.poolmanager | 97 | 48 | 0 | 51%
requests.packages.urllib3.request | 30 | 16 | 0 | 47%
requests.packages.urllib3.response | 140 | 56 | 0 | 60%
requests.packages.urllib3.util | 6 | 0 | 0 | 100%
requests.packages.urllib3.util.connection | 27 | 23 | 0 | 15%
requests.packages.urllib3.util.request | 21 | 17 | 0 | 19%
requests.packages.urllib3.util.response | 4 | 1 | 0 | 75%
requests.packages.urllib3.util.ssl_ | 59 | 43 | 0 | 27%
requests.packages.urllib3.util.timeout | 57 | 23 | 0 | 60%
requests.packages.urllib3.util.url | 69 | 24 | 0 | 65%
requests.sessions | 237 | 106 | 0 | 55%
requests.status_codes | 8 | 0 | 0 | 100%
requests.structures | 55 | 20 | 0 | 64%
requests.utils | 315 | 204 | 0 | 35%
rfc822 | 574 | 574 | 0 | 0%
shlex | 229 | 229 | 0 | 0%
sqlite3 | 1 | 1 | 0 | 0%
sqlite3.dbapi2 | 41 | 41 | 0 | 0%
stringprep | 65 | 65 | 0 | 0%
urllib2 | 820 | 820 | 0 | 0%
uuid | 295 | 295 | 0 | 0%
xml.dom.pulldom | 270 | 270 | 0 | 0%
xml.etree | 0 | 0 | 0 | 100%
xml.etree.ElementPath | 181 | 181 | 0 | 0%
xml.etree.ElementTree | 736 | 736 | 0 | 0%
xml.etree.cElementTree | 1 | 1 | 0 | 0%
xml.parsers | 0 | 0 | 0 | 100%
xml.parsers.expat | 2 | 2 | 0 | 0%